---
title: 퀵 가이드
category: 퀵 가이드 (서비스 한 눈에 보기) > 퀵 가이드 > 퀵 가이드
seo:
  title: 퀵 가이드
  description: >-
    포트원이 제공하는 퀵가이드입니다. 포트원 서비스 사용전 준비사항, 사이트 구축, 테스트환경 연동, 결제대행사 계약, 실 운영환경,
    상점아이디 추가까지 필요하신 정보응 빠르게 확인해보세요.
  keywords:
    - 퀵가이드
    - PG사 계약
    - PG사
    - 결제대행사 선정
    - 결제
    - 결제대행사 계약
tags:
  - 퀵가이드
pgCompanies:
  - 공통
searchTags:
  - 포트원이용절차
  - 포트원사용방법
  - 이용방법
  - 사용방법
  - 한눈에보기
  - 빠른가이드
  - 퀵가이드
---



## <Highlight text="미리 준비하기" />



#### **결제대행사 선정하기**

서비스 이용 전, 결제대행사와 결제수단 등의 기준으로 이용하실 결제대행사를 결정하실 수 있습니다. \
각 결제대행사별로 지원하는 결제수단과 연동방식이 다르므로, 먼저 구현하고자 하는 서비스 형태를 구상해 보시는 것을 추천드립니다.

1\. 결제수단 기준으로 선정하기

<Indent level="1">

- 신용카드,계좌이체,가상계좌,간편결제(카카오페이,토스페이 등)중 어떤 서비스를 도입할지 결정합니다.
- 원하는 결제수단을 지원하는 결제대행사를 확인합니다.
  - [결제대행사별 지원 결제수단 보러가기↗](https://help.portone.io/category/service)

</Indent>

2\. 연동방식 기준으로 선정하기

<Indent level="1">

- 결제대행사의 결제화면(결제창)을 띄워서 앱카드와 같은 인증과정을 거칠지, 아니면 결제화면 UI를 직접 구현할지 결정합니다.
- 원하는 연동방식을 지원하는 결제대행사를 확인합니다.

</Indent>

3\. 비용을 기준으로 선정하기

<Indent level="1">

- 결제대행사에서 제공하는 수수료 기준을 비교하여 검토한 뒤 최종 결정합니다.

</Indent>

#### **사이트 구축하기**

결제대행사 계약을 위해 연동하실 사이트를 미리 구축 해야 합니다.\
계약 진행 시 첫 번째 심사 단계에서 사이트 구축 여부를 가장 먼저 확인 하오니, 전자결제 신청(결제대행사(PG) 계약신청) 전에 미리 구현해 놓으시는 것을 추천드립니다. \
참고로 모든 서비스가 '완벽하게' 구현되어 있지 않아도 되며, 반드시 구현되어 있어야 하는 필수 항목을 위주로 먼저 구현하셔도 무방합니다.

<Callout title="서비스 필수 구축요건 보러가기↗" />

## <Highlight text="테스트 연동" />



결제대행사와의 계약 전이거나 개발이 완료되지 않았더라도 연동 개발을 미리 진행해보실 수 있습니다.

결제대행사와의 계약을 수월하게 하기 위하여 사이트를 구축하시면서 미리 연동 개발까지 진행해 보시는 것이 좋습니다.
또한 연동 테스트를 진행하시면서 결제대행사(PG)의 결제수단 및 연동방식이 준비하시는 서비스에 적합한지 미리 검토해보실 수 있습니다.\
(단, 테스트 환경에서 일부 결제수단 및 방식의 이용이 제한되는 경우가 있을 수 있습니다. )

테스트환경 연동은 포트원에서 제공하는 공용 테스트용 연동 정보로 가능하며, 연동 가이드를 참고하시어 설정 후 이용해 주시길 바랍니다.



<Callout content="" title="결제대행사별 테스트연동 방법 보러가기↗︎" />

## <Highlight text="결제대행사 계약" />



#### **가입신청**

포트원 관리자콘솔에서 이용하실 결제대행사와 결제수단을 선택하여 신청서를 접수해주세요. \
이후 절차는 모두 메일로 안내가 이루어집니다. 모든 결제대행사의 가입신청 프로세스는 동일합니다.



#### **입점심사**

포트원 관리자콘솔에서 신청서 접수 후 영업일 기준 3일 이내로 다음절차가 메일로 안내됩니다.
결제대행사별로 해당 절차에 대한 프로세스가 다르므로 이용하시는 결제대행사에 맞게 계약절차를 참고해주세요.

#### **계약서 작성**

계약은 결제대행사 ↔️ 고객사  양사간에 진행됩니다. 계약서 및 구비서류는 결제대행사에서 안내되는 기준으로 작성하신 뒤, 결제대행사 측으로 전달해주시기 바랍니다. 보통 해당 단계까지 완료하시면 계약이 마무리되며, 영업일 기준 1주 정도 소요됩니다.

#### **카드사 심사**

카드사 심사를 위해  서비스 사이트에 결제 연동을 진행해야 합니다.
연동이 완료되었다면 계약을 진행하신 결제대행사로 카드사 심사를 요청해야 합니다. 카드사별로 심사가 각각 이루어지기 때문에 최종적으로 약 2주 정도 소요됩니다.

<Callout content="" title="전자결제 신청절차 보러가기↗︎" />

## <Highlight text="운영 환경 연동" />



결제대행사와의 계약 및 카드사 심사가 완료되면 결제대행사에서 실제로 사용이 가능한 연동 정보(상점아이디 등)를 발급해 드립니다.
해당 연동 정보로 운영하시는 사이트에 적용한 뒤 결제가 발생되면  사업자의 매출로 연결됩니다. 실 운영 환경으로 연동하는 방법은 기본적으로 두 가지 절차가 진행되어야 합니다.

#### **실 모드 연동**

결제대행사로부터 전달받은  실 운영용 연동 정보를 포트원 관리자콘솔 내 \[결제 연동] → \[연동 관리] → \[채널 관리] 페이지에 추가해야 합니다.
포트원 모듈을 연동하는 경우 관리자콘솔에 등록된 채널을 기반으로 결제를 요청하므로 아래 절차를 필수로 진행해야 합니다.
결제대행사별로 연동 정보 명칭 및 정보 확인 절차가 다르므로 결제대행사별 채널 연동 가이드를 잘 참고하여 설정해 주세요.



#### **서비스 연동 · 개발**

이용하는 서비스에서 결제 요청 시 실제 운영용 채널로 요청하도록 코드를 변경해야 합니다.\
안정적인 연동을 위해 pg 파라미터 또는 channelKey 파라미터에 결제를 요청하고자 하는 채널을 지정한 후 호출하도록 구현해야 합니다.\
자세한 설명은 개발자센터 내 연동가이드를 참고하여 구현해 주세요.

<Callout content="1. 서비스 오픈 전 내부적으로 결제 및 환불 절차를 충분히 테스트해야 합니다.
2. 운영용 상점아이디로 결제가 발생되는지 확인해야 합니다.
3. 만약 카드사 심사가 완료되지 않았다면 카드사 심사 완료 후 서비스를 오픈하시기를 권장드립니다. 카드사 심사 완료 전 결제를 시도하는 경우 해당 카드는 결제 실패가 발생하오니 유의하시기 바랍니다." title="참고사항" icon="💡" />

<Callout content="" title="결제대행사별 실 연동 방법 보러가기↗︎" />

## <Highlight text="상점아이디 추가" />



서비스 운영 중에 필요에 따라 결제수단을 추가하거나 서비스(사이트)를 새롭게 추가할 때 상점아이디를 추가하는 상황이 발생할 수 있습니다.
추가되는 항목에 따라 기존 상점아이디를 유지하거나 새로운 상점아디를 추가 발급 받아야합니다.

상점아이디를 추가 발급해야하는 경우는 다음과 같습니다.

<Indent level="1">

- 결제방식이 달라지는 경우 (일반결제 / 정기결제)
- 정산방법, 정산계좌 등 계약내용이 달라지는 경우\
  (결제대행사에 따라 추가가 필요치 않을 수 있습니다)
- 기존에 심사받은 서비스와 다른 서비스인 경우 (업종/판매상품이 완전히 변경되는 경우)
- 사업자가 변경되는 경우 (이 경우 계약을 새롭게 진행해야 합니다)

</Indent>

<Callout content="" title="상점아이디 추가 방법 보러가기↗︎" />
